@@ -1,8 +1,7 @@
-from .ext import telegram
-import sys
-import os
+import sys, os, re
 import importlib.util
-import re
+
+from .apihelper import telegram # telebot.py
 
 __all__ = ["telegram"]
 
@@ -11,12 +10,14 @@ def main():
         command = sys.argv[1]
         
         if command.startswith('run:'):
-            filename = command[4:]
+            parts = command[4:].split()
+            filename = parts[0]
+            
             run_bot_file(filename)
         else:
-            print("Usage: mehta run:<filename>")
+            print("bash: mehta run:<filename>")
     else:
-        print("Usage: mehta run:<filename>")
+        print("bash: mehta run:<filename>")
 
 def run_bot_file(filename):
     try:
@@ -24,7 +25,7 @@ def run_bot_file(filename):
             filename += '.py'
         
         if not os.path.exists(filename):
-            print(f"Error: File with {filename} not found")
+            print(f"Error: File {filename} not found")
             return
         
         with open(filename, 'r') as f:
@@ -42,8 +43,6 @@ def run_bot_file(filename):
                 module.bot.run(token)
             else:
                 print("Error: No bot instance found in file")
-        else:
-            print("Error: No bot token found in file")
                 
     except Exception as e:
         print(f"Error: {e}")
\ No newline at end of file
